@@ -22,7 +22,7 @@
 #' \describe{
 #' \item{fit}{the fitted object of class `"gmm"` from the call to [gmm::gmm()].}
 #' \item{estci}{a matrix of the estimates with their corresponding confidence interval limits.}
-#' \item{link}{a character vector containing the specificed link function.}
+#' \item{link}{a character vector containing the specified link function.}
 #' }
 #' @references
 #' Bowden J, Vansteelandt S.
@@ -92,30 +92,30 @@ tsri <- function(formula, instruments, data, subset, na.action,
   # code from beginning for ivreg::ivreg()
   ## set up model.frame() call
   cl <- match.call()
-  if(missing(data)) data <- environment(formula)
+  if (missing(data)) data <- environment(formula)
   mf <- match.call(expand.dots = FALSE)
   m <- match(c("formula", "data", "subset", "na.action", "weights", "offset"), names(mf), 0)
   mf <- mf[c(1, m)]
   mf$drop.unused.levels <- TRUE
   ## handle instruments for backward compatibility
-  if(!missing(instruments)) {
+  if (!missing(instruments)) {
     formula <- Formula::as.Formula(formula, instruments)
     cl$instruments <- NULL
     cl$formula <- formula(formula)
   } else {
     formula <- Formula::as.Formula(formula)
   }
-  if(length(formula)[2L] == 3L) formula <- Formula::as.Formula(
+  if (length(formula)[2L] == 3L) formula <- Formula::as.Formula(
     formula(formula, rhs = c(2L, 1L), collapse = TRUE),
     formula(formula, lhs = 0L, rhs = c(3L, 1L), collapse = TRUE)
   )
   stopifnot(length(formula)[1L] == 1L, length(formula)[2L] %in% 1L:2L)
   ## try to handle dots in formula
   has_dot <- function(formula) inherits(try(stats::terms(formula), silent = TRUE), "try-error")
-  if(has_dot(formula)) {
+  if (has_dot(formula)) {
     f1 <- formula(formula, rhs = 1L)
     f2 <- formula(formula, lhs = 0L, rhs = 2L)
-    if(!has_dot(f1) & has_dot(f2)) formula <- Formula::as.Formula(f1,
+    if (!has_dot(f1) && has_dot(f2)) formula <- Formula::as.Formula(f1,
                                                                   stats::update(formula(formula, lhs = 0L, rhs = 1L), f2))
   }
   ## call model.frame()
@@ -127,7 +127,7 @@ tsri <- function(formula, instruments, data, subset, na.action,
   mt <- stats::terms(formula, data = data)
   mtX <- stats::terms(formula, data = data, rhs = 1)
   X <- stats::model.matrix(mtX, mf, contrasts)
-  if(length(formula)[2] < 2L) {
+  if (length(formula)[2] < 2L) {
     mtZ <- NULL
     Z <- NULL
   } else {
@@ -151,7 +151,7 @@ tsri <- function(formula, instruments, data, subset, na.action,
   tsri_env$anycovs <- FALSE
   if (!identical(covariatenames, character(0))) {
     tsri_env$anycovs <- TRUE
-    covariates <- X[,covariatenames]
+    covariates <- X[, covariatenames]
   }
 
   tsri_env$xnames <- xnames[!(xnames %in% covariatenames)]
@@ -162,31 +162,28 @@ tsri <- function(formula, instruments, data, subset, na.action,
   link <- match.arg(link, c("identity", "logadd", "logmult", "logit"))
 
   # check y binary
-  if (link == "logit" & !all(Y %in% 0:1))
+  if (link == "logit" && !all(Y %in% 0:1))
     stop("With the logit link, the outcome must be binary, i.e. take values 0 or 1.")
 
   # initial values
   if (is.null(t0)) {
-    stage1 <- stats::lm(X[,2] ~ -1 + Z)
+    stage1 <- stats::lm(X[, 2] ~ -1 + Z)
     t0 <- stats::coef(stage1)
     res <- stats::residuals(stage1)
     if (tsri_env$anycovs) {
       res <- cbind(res, covariates)
     }
     if (link == "identity") {
-      stage2 <- stats::lm(Y ~ X[,2] + res)
-    }
-    else if (link == "logadd") {
-      stage2 <- stats::glm(Y ~ X[,2] + res, family = stats::poisson(link = "log"))
-    }
-    else if (link == "logmult") {
+      stage2 <- stats::lm(Y ~ X[, 2] + res)
+    } else if (link == "logadd") {
+      stage2 <- stats::glm(Y ~ X[, 2] + res, family = stats::poisson(link = "log"))
+    } else if (link == "logmult") {
       Ystar <- Y
       Ystar[Y == 0] <- 0.001
-      stage2 <- stats::glm(Ystar ~ X[,2] + res, family = stats::Gamma(link = "log"),
+      stage2 <- stats::glm(Ystar ~ X[, 2] + res, family = stats::Gamma(link = "log"),
                     control = list(maxit = 1E5))
-    }
-    else if (link == "logit") {
-      stage2 <- stats::glm(Y ~ X[,2] + res, family = stats::binomial(link = "logit"))
+    } else if (link == "logit") {
+      stage2 <- stats::glm(Y ~ X[, 2] + res, family = stats::binomial(link = "logit"))
     }
     t0 <- c(t0, stats::coef(stage2))
 
@@ -203,20 +200,19 @@ tsri <- function(formula, instruments, data, subset, na.action,
   Ztopass <- as.data.frame(Z[, -1])
   if (tsri_env$anycovs) {
     colnames(Ztopass) <- c(tsri_env$znames, tsri_env$covariatenames)
-  }
-  else {
+  } else {
     colnames(Ztopass) <- tsri_env$znames
   }
 
   # functions for tsri fit
-  tsri_gmm <- function(x, y, z, xnames, t0, link){
+  tsri_gmm <- function(x, y, z, xnames, t0, link) {
     x <- as.matrix(x)
 
     if (!identical(tsri_env$covariatenames, character(0))) {
-      x <- x[,!(colnames(x) %in% tsri_env$covariatenames), drop = FALSE]
+      x <- x[, !(colnames(x) %in% tsri_env$covariatenames), drop = FALSE]
     }
 
-    dat = data.frame(y, x, z)
+    dat <- data.frame(y, x, z)
 
     if (is.null(t0))
       t0 <- rep(0, ncol(x) + 1)
@@ -224,15 +220,12 @@ tsri <- function(formula, instruments, data, subset, na.action,
     # gmm fit
     if (link == "identity") {
       fit <- gmm::gmm(tsriIdentityMoments, x = dat, t0 = t0, vcov = "iid")
-    }
-    else if (link == "logadd") {
+    } else if (link == "logadd") {
       fit <- gmm::gmm(tsriLogaddMoments, x = dat, t0 = t0, vcov = "iid")
-    }
-    else if (link == "logmult") {
+    } else if (link == "logmult") {
       fit <- gmm::gmm(tsriLogmultMoments, x = dat, t0 = t0, vcov = "iid",
                       itermax = 1E7)
-    }
-    else if (link == "logit") {
+    } else if (link == "logit") {
       fit <- gmm::gmm(tsriLogitMoments, x = dat, t0 = t0, vcov = "iid")
     }
 
@@ -248,9 +241,9 @@ tsri <- function(formula, instruments, data, subset, na.action,
     return(reslist)
   }
 
-  tsriIdentityMoments <- function(theta, x){
+  tsriIdentityMoments <- function(theta, x) {
     # extract variables from x
-    Y <- as.matrix(x[,"y"])
+    Y <- as.matrix(x[, "y"])
     X <- x[, tsri_env$xnames]
     Z <- as.matrix(x[, tsri_env$znames])
     nZ <- ncol(Z)
@@ -286,41 +279,40 @@ tsri <- function(formula, instruments, data, subset, na.action,
     # moments
     moments <- matrix(nrow = nrow(x), ncol = length(theta), NA)
 
-    moments[,1] <- (X - linearpredictor)
+    moments[, 1] <- (X - linearpredictor)
 
     for (i in 2:stage1end) {
-      moments[,i] <- (X - linearpredictor)*Zwithcons[,i]
+      moments[, i] <- (X - linearpredictor) * Zwithcons[, i]
     }
 
     if (tsri_env$anycovs) {
       stage2express <- (Y - (theta[stage2start] +
-                               thetacausal*X +
+                               thetacausal * X +
                                thetares * (X - as.matrix(linearpredictor)) +
                                as.matrix(covariates) %*% as.matrix(thetacov)))
-    }
-    else {
+    } else {
       stage2express <- (Y - (theta[stage2start] +
-                               thetacausal*X +
+                               thetacausal * X +
                                thetares * (X - as.matrix(linearpredictor))))
     }
 
     thetastart <- stage2start + 1
 
-    moments[,stage2start] <- stage2express
+    moments[, stage2start] <- stage2express
 
     start3 <- stage2start + 1
     j <- 1
     for (i in start3:thetaend) {
-      moments[,i] <- (stage2express)*res[,j]
+      moments[, i] <- (stage2express) * res[, j]
       j <- j + 1
     }
 
     return(moments)
   }
 
-  tsriLogaddMoments <- function(theta, x){
+  tsriLogaddMoments <- function(theta, x) {
     # extract variables from x
-    Y <- as.matrix(x[,"y"])
+    Y <- as.matrix(x[, "y"])
     X <- x[, tsri_env$xnames]
     Z <- as.matrix(x[, tsri_env$znames])
     nZ <- ncol(Z)
@@ -356,41 +348,40 @@ tsri <- function(formula, instruments, data, subset, na.action,
     # moments
     moments <- matrix(nrow = nrow(x), ncol = length(theta), NA)
 
-    moments[,1] <- (X - linearpredictor)
+    moments[, 1] <- (X - linearpredictor)
 
     for (i in 2:stage1end) {
-      moments[,i] <- (X - linearpredictor)*Zwithcons[,i]
+      moments[, i] <- (X - linearpredictor) * Zwithcons[, i]
     }
 
     if (tsri_env$anycovs) {
       stage2express <- (Y - exp(theta[stage2start] +
-                                  thetacausal*X +
+                                  thetacausal * X +
                                   thetares * (X - as.matrix(linearpredictor)) +
                                   as.matrix(covariates) %*% as.matrix(thetacov)))
-    }
-    else {
+    } else {
       stage2express <- (Y - exp(theta[stage2start] +
-                                  thetacausal*X +
+                                  thetacausal * X +
                                   thetares * (X - as.matrix(linearpredictor))))
     }
 
     thetastart <- stage2start + 1
 
-    moments[,stage2start] <- stage2express
+    moments[, stage2start] <- stage2express
 
     start3 <- stage2start + 1
     j <- 1
     for (i in start3:thetaend) {
-      moments[,i] <- (stage2express)*res[,j]
+      moments[, i] <- (stage2express) * res[, j]
       j <- j + 1
     }
 
     return(moments)
   }
 
-  tsriLogmultMoments <- function(theta, x){
+  tsriLogmultMoments <- function(theta, x) {
     # extract variables from x
-    Y <- as.matrix(x[,"y"])
+    Y <- as.matrix(x[, "y"])
     X <- x[, tsri_env$xnames]
     Z <- as.matrix(x[, tsri_env$znames])
     nZ <- ncol(Z)
@@ -426,41 +417,40 @@ tsri <- function(formula, instruments, data, subset, na.action,
     # moments
     moments <- matrix(nrow = nrow(x), ncol = length(theta), NA)
 
-    moments[,1] <- (X - linearpredictor)
+    moments[, 1] <- (X - linearpredictor)
 
     for (i in 2:stage1end) {
-      moments[,i] <- (X - linearpredictor)*Zwithcons[,i]
+      moments[, i] <- (X - linearpredictor) * Zwithcons[, i]
     }
 
     if (tsri_env$anycovs) {
-      stage2express <- (Y * exp(-1*(theta[stage2start] +
-                                      thetacausal*X +
+      stage2express <- (Y * exp(-1 * (theta[stage2start] +
+                                      thetacausal * X +
                                       thetares * (X - as.matrix(linearpredictor)) +
                                       as.matrix(covariates) %*% as.matrix(thetacov))) - 1)
-    }
-    else {
-      stage2express <- (Y * exp(-1*(theta[stage2start] +
-                                      thetacausal*X +
+    } else {
+      stage2express <- (Y * exp(-1 * (theta[stage2start] +
+                                      thetacausal * X +
                                       thetares * (X - as.matrix(linearpredictor)))) - 1)
     }
 
     thetastart <- stage2start + 1
 
-    moments[,stage2start] <- stage2express
+    moments[, stage2start] <- stage2express
 
     start3 <- stage2start + 1
     j <- 1
     for (i in start3:thetaend) {
-      moments[,i] <- (stage2express)*res[,j]
+      moments[, i] <- (stage2express) * res[, j]
       j <- j + 1
     }
 
     return(moments)
   }
 
-  tsriLogitMoments <- function(theta, x){
+  tsriLogitMoments <- function(theta, x) {
     # extract variables from x
-    Y <- as.matrix(x[,"y"])
+    Y <- as.matrix(x[, "y"])
     X <- x[, tsri_env$xnames]
     Z <- as.matrix(x[, tsri_env$znames])
     nZ <- ncol(Z)
@@ -496,32 +486,31 @@ tsri <- function(formula, instruments, data, subset, na.action,
     # moments
     moments <- matrix(nrow = nrow(x), ncol = length(theta), NA)
 
-    moments[,1] <- (X - linearpredictor)
+    moments[, 1] <- (X - linearpredictor)
 
     for (i in 2:stage1end) {
-      moments[,i] <- (X - linearpredictor)*Zwithcons[,i]
+      moments[, i] <- (X - linearpredictor) * Zwithcons[, i]
     }
 
     if (tsri_env$anycovs) {
       stage2express <- (Y - stats::plogis(theta[stage2start] +
-                                     thetacausal*X +
+                                     thetacausal * X +
                                      thetares * (X - as.matrix(linearpredictor)) +
                                      as.matrix(covariates) %*% as.matrix(thetacov)))
-    }
-    else {
+    } else {
       stage2express <- (Y - stats::plogis(theta[stage2start] +
-                                     thetacausal*X +
+                                     thetacausal * X +
                                      thetares * (X - as.matrix(linearpredictor))))
     }
 
     thetastart <- stage2start + 1
 
-    moments[,stage2start] <- stage2express
+    moments[, stage2start] <- stage2express
 
     start3 <- stage2start + 1
     j <- 1
     for (i in start3:thetaend) {
-      moments[,i] <- (stage2express)*res[,j]
+      moments[, i] <- (stage2express) * res[, j]
       j <- j + 1
     }
 
@@ -583,7 +572,7 @@ print.tsri <- function(x, digits = max(3, getOption("digits") - 3), ...) {
     if (x$link %in% c("logadd", "logmult"))
       parname <- "Causal risk ratio"
     cat("\n", parname, " with 95% CI limits:\n", sep = "")
-    print(exp(x$estci[rowstart:rowstop,]), digits = digits, ...)
+    print(exp(x$estci[rowstart:rowstop, ]), digits = digits, ...)
   }
 
   cat("\n")
@@ -606,7 +595,7 @@ print.summary.tsri <- function(x, digits = max(3, getOption("digits") - 3), ...)
     if (x$object$link %in% c("logadd", "logmult"))
       parname <- "Causal risk ratio"
     cat("\n", parname, " with 95% CI limits:\n", sep = "")
-    print(exp(x$object$estci[rowstart:rowstop,]), digits = digits, ...)
+    print(exp(x$object$estci[rowstart:rowstop, ]), digits = digits, ...)
   }
 
   cat("\n")
