@@ -23,11 +23,11 @@ summary(mod)
 fsw(mod)
 
 ## -----------------------------------------------------------------------------
-modst2 <- felm(lwage ~ 1 | 0 | (educ | exper ~ age + kidslt6 + kidsge6),
-                 data = dat)
+modst2 <- felm(lwage ~ 1 |
+                 0 | (educ | exper ~ age + kidslt6 + kidsge6), data = dat)
 summary(modst2)
-t(sapply(modst2$stage1$lhs, 
-         function(lh) waldtest(modst2$stage1, 
-                               ~ age | kidslt6 | kidsge6, lhs = lh)))
+t(sapply(modst2$stage1$lhs, function(lh) {
+  waldtest(modst2$stage1, ~ age | kidslt6 | kidsge6, lhs = lh)
+}))
 condfstat(modst2, quantiles = c(0.025, 0.975))
 
